aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/engine/gc.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/sci/engine/gc.h')
-rw-r--r--engines/sci/engine/gc.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/engines/sci/engine/gc.h b/engines/sci/engine/gc.h
index aa7b91264e..f255ea6c76 100644
--- a/engines/sci/engine/gc.h
+++ b/engines/sci/engine/gc.h
@@ -48,15 +48,15 @@ struct reg_t_Hash {
// The reg_t_hash_map is actually really a hashset
typedef Common::HashMap<reg_t, bool, reg_t_Hash, reg_t_EqualTo> reg_t_hash_map;
-reg_t_hash_map *find_all_used_references(state_t *s);
+reg_t_hash_map *find_all_used_references(EngineState *s);
/* Finds all used references and normalises them to their memory addresses
** Parameters: (state_t *) s: The state to gather all information from
** Returns : (reg_t_hash_map *) A hash map containing entries for all used references
*/
-void run_gc(state_t *s);
+void run_gc(EngineState *s);
/* Runs garbage collection on the current system state
** Parameters: (state_t *) s: The state in which we should gc
*/
} // End of namespace Sci
@@ -48,15 +48,15 @@ struct reg_t_Hash {
/* Finds all used references and normalises them to their memory addresses
-** Parameters: (state_t *) s: The state to gather all information from
+** Parameters: (EngineState *) s: The state to gather all information from
** Returns : (reg_t_hash_map *) A hash map containing entries for all used references
*/
@@ -48,15 +48,15 @@ struct reg_t_Hash {
/* Runs garbage collection on the current system state
-** Parameters: (state_t *) s: The state in which we should gc
+** Parameters: (EngineState *) s: The state in which we should gc
*/
} // End of namespace Sci